@@ -20,7 +20,7 @@ class CMakeToolsPlugin : public KTextEditor::Plugin
     Q_OBJECT
 
 public:
-    explicit CMakeToolsPlugin(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
+    explicit CMakeToolsPlugin(QObject *parent = nullptr, const QVariantList & = QVariantList());
 
     ~CMakeToolsPlugin() override;
 
