@@ -4,14 +4,15 @@
  *
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
-#ifndef KTEXTEDITOR_KATE_EXTERNALTOOL_H
-#define KTEXTEDITOR_KATE_EXTERNALTOOL_H
+#pragma once
 
 #include <QMetaType>
 #include <QString>
 #include <QStringList>
 #include <QUrl>
 
+#include <optional>
+
 class KConfigGroup;
 
 /**
@@ -88,7 +89,18 @@ public:
 
 public:
     /// This is set when loading the Tool from disk.
-    bool hasexec = false;
+    /// If the tool has an expandable variable, this will nullopt
+    std::optional<bool> hasexec = false;
+
+    /**
+     * @return true if the executable has a valid executable.
+     * Will also return true, if the execuable contains an
+     * expandable variable
+     */
+    bool canExecute() const
+    {
+        return !hasexec || (hasexec.has_value() && hasexec.value() == true);
+    }
 
     /**
      * @return true if the @p mimetype matches.
@@ -158,6 +170,4 @@ bool operator==(const KateExternalTool &lhs, const KateExternalTool &rhs);
 // for use in QVariant (QAction::setData() and QAction::data())
 Q_DECLARE_METATYPE(KateExternalTool *)
 
-#endif // KTEXTEDITOR_KATE_EXTERNALTOOL_H
-
 // kate: space-indent on; indent-width 4; replace-tabs on;
