@@ -87,7 +87,8 @@ void KateFileTreePlugin::applyConfig(bool shadingEnabled,
                                      int sortRole,
                                      bool showFullPath,
                                      bool showToolbar,
-                                     bool showCloseButton)
+                                     bool showCloseButton,
+                                     bool middleClickToClose)
 {
     // save to settings
     m_settings.setShadingEnabled(shadingEnabled);
@@ -99,10 +100,11 @@ void KateFileTreePlugin::applyConfig(bool shadingEnabled,
     m_settings.setShowFullPathOnRoots(showFullPath);
     m_settings.setShowToolbar(showToolbar);
     m_settings.setShowCloseButton(showCloseButton);
+    m_settings.middleClickToClose = middleClickToClose;
     m_settings.save();
 
     // update views
-    for (KateFileTreePluginView *view : qAsConst(m_views)) {
+    for (KateFileTreePluginView *view : std::as_const(m_views)) {
         view->setHasLocalPrefs(false);
         view->model()->setShadingEnabled(shadingEnabled);
         view->model()->setViewShade(viewShade);
@@ -113,6 +115,7 @@ void KateFileTreePlugin::applyConfig(bool shadingEnabled,
         view->model()->setShowFullPathOnRoots(showFullPath);
         view->setToolbarVisible(showToolbar);
         view->tree()->setShowCloseButton(showCloseButton);
+        view->tree()->setMiddleClickToClose(middleClickToClose);
     }
 }
 
@@ -149,6 +152,7 @@ KateFileTreePluginView::KateFileTreePluginView(KTextEditor::MainWindow *mainWind
     m_fileTree = new KateFileTree(m_mainWindow, m_toolView);
     m_fileTree->setSortingEnabled(true);
     m_fileTree->setShowCloseButton(m_plug->settings().showCloseButton());
+    m_fileTree->setMiddleClickToClose(m_plug->settings().middleClickToClose);
     m_fileTree->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::TopEdge}));
 
     connect(m_fileTree, &KateFileTree::activateDocument, this, &KateFileTreePluginView::activateDocument);
@@ -189,6 +193,10 @@ KateFileTreePluginView::KateFileTreePluginView(KTextEditor::MainWindow *mainWind
     m_documentsCreatedTimer.setInterval(0);
     connect(&m_documentsCreatedTimer, &QTimer::timeout, this, &KateFileTreePluginView::slotDocumentsCreated);
 
+    m_proxyInvalidateTimer.setSingleShot(true);
+    m_proxyInvalidateTimer.setInterval(10);
+    m_proxyInvalidateTimer.callOnTimeout(proxy(), &QSortFilterProxyModel::invalidate);
+
     connect(m_documentModel, &KateFileTreeModel::triggerViewChangeAfterNameChange, this, [this] {
         viewChanged();
     });
@@ -200,17 +208,14 @@ KateFileTreePluginView::KateFileTreePluginView(KTextEditor::MainWindow *mainWind
 
     connect(mainWindow, &KTextEditor::MainWindow::viewChanged, this, &KateFileTreePluginView::viewChanged);
 
-    auto mw = mainWindow->window();
-    connect(mw, SIGNAL(widgetAdded(QWidget *)), this, SLOT(slotWidgetCreated(QWidget *)));
-    connect(mw, SIGNAL(widgetRemoved(QWidget *)), this, SLOT(slotWidgetRemoved(QWidget *)));
+    connect(mainWindow, &KTextEditor::MainWindow::widgetAdded, this, &KateFileTreePluginView::slotWidgetCreated);
+    connect(mainWindow, &KTextEditor::MainWindow::widgetRemoved, this, &KateFileTreePluginView::slotWidgetRemoved);
 
     connect(m_fileTree, &KateFileTree::closeWidget, this, [this](QWidget *w) {
-        auto mw = m_mainWindow->window();
-        QMetaObject::invokeMethod(mw, "removeWidget", Q_ARG(QWidget *, w));
+        m_mainWindow->removeWidget(w);
     });
     connect(m_fileTree, &KateFileTree::activateWidget, this, [this](QWidget *w) {
-        auto mw = m_mainWindow->window();
-        QMetaObject::invokeMethod(mw, "activateWidget", Q_ARG(QWidget *, w));
+        m_mainWindow->activateWidget(w);
     });
 
     //
@@ -261,12 +266,14 @@ void KateFileTreePluginView::setupActions()
     aShowActive->setIcon(QIcon::fromTheme(QStringLiteral("folder-sync")));
     connect(aShowActive, &QAction::triggered, this, &KateFileTreePluginView::showActiveDocument);
 
-    auto aSave = actionCollection()->addAction(QStringLiteral("filetree_save"), this, SLOT(slotDocumentSave()));
+    auto aSave = actionCollection()->addAction(QStringLiteral("filetree_save"));
+    connect(aSave, &QAction::triggered, this, &KateFileTreePluginView::slotDocumentSave);
     aSave->setText(i18n("Save"));
     aSave->setToolTip(i18n("Save the current document"));
     aSave->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
 
-    auto aSaveAs = actionCollection()->addAction(QStringLiteral("filetree_save_as"), this, SLOT(slotDocumentSaveAs()));
+    auto aSaveAs = actionCollection()->addAction(QStringLiteral("filetree_save_as"));
+    connect(aSaveAs, &QAction::triggered, this, &KateFileTreePluginView::slotDocumentSaveAs);
     aSaveAs->setText(i18n("Save As"));
     aSaveAs->setToolTip(i18n("Save the current document under a new name"));
     aSaveAs->setIcon(QIcon::fromTheme(QStringLiteral("document-save-as")));
@@ -325,7 +332,7 @@ void KateFileTreePluginView::documentOpened(KTextEditor::Document *doc)
 void KateFileTreePluginView::documentClosed(KTextEditor::Document *doc)
 {
     m_documentsCreated.removeAll(doc);
-    m_proxyModel->invalidate();
+    m_proxyInvalidateTimer.start();
 }
 
 void KateFileTreePluginView::setToolbarVisible(bool visible)
@@ -335,9 +342,7 @@ void KateFileTreePluginView::setToolbarVisible(bool visible)
 
 void KateFileTreePluginView::viewChanged(KTextEditor::View *)
 {
-    auto mw = m_mainWindow->window();
-    QWidget *activeWidget = nullptr;
-    QMetaObject::invokeMethod(mw, "activeWidget", Q_RETURN_ARG(QWidget *, activeWidget));
+    QWidget *activeWidget = m_mainWindow->activeWidget();
     if (!activeWidget) {
         return;
     }
