@@ -44,6 +44,10 @@
 #include "targets.h"
 #include "ui_build.h"
 
+class KateBuildPlugin;
+
+class QCMakeFileApi;
+
 /******************************************************************/
 class KateBuildView : public QObject, public KXMLGUIClient, public KTextEditor::SessionConfigInterface
 {
@@ -58,7 +62,7 @@ public:
 
     enum class Category { Normal, Info, Warning, Error };
 
-    KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindow *mw);
+    KateBuildView(KateBuildPlugin *plugin, KTextEditor::MainWindow *mw);
     ~KateBuildView() override;
 
     void readSessionConfig(const KConfigGroup &config) override;
@@ -68,6 +72,11 @@ public:
 
     QUrl docUrl();
 
+    void sendError(const QString &);
+
+public Q_SLOTS:
+    void loadCMakeTargets(const QString &cmakeFile);
+
 private Q_SLOTS:
 
     // Building
@@ -75,8 +84,11 @@ private Q_SLOTS:
     void slotBuildSelectedTarget();
     void slotBuildAndRunSelectedTarget();
     void slotBuildPreviousTarget();
+    void slotCompileCurrentFile();
     bool slotStop();
 
+    void slotLoadCMakeTargets();
+
     // Parse output
     void slotProcExited(int exitCode, QProcess::ExitStatus exitStatus);
     void slotReadReadyStdErr();
@@ -84,13 +96,6 @@ private Q_SLOTS:
     void slotRunAfterBuild();
     void updateTextBrowser();
 
-    // Settings
-    void targetSetNew();
-    void targetOrSetCopy();
-    void targetDelete();
-
-    void slotAddTargetClicked();
-
     void handleEsc(QEvent *e);
 
     /**
@@ -100,16 +105,13 @@ private Q_SLOTS:
     void slotPluginViewDeleted(const QString &name, QObject *pluginView);
     void slotProjectMapChanged();
 
-    /**
-     * Read the non-session configurations
-     */
-    void readConfig();
-
     /**
      * Save the project build target updates
      */
     void saveProjectTargets();
 
+    void enableCompileCurrentFile();
+
 protected:
     bool eventFilter(QObject *obj, QEvent *ev) override;
 
@@ -123,6 +125,20 @@ private:
         int column;
     };
 
+    // Support for compile_commands.json
+    struct CompileCommand {
+        QString workingDir;
+        QString command;
+    };
+
+    struct CompileCommands {
+        std::map<QString /* file*/, CompileCommand> commands;
+        QString filename;
+        QDateTime date;
+    };
+
+    CompileCommands m_parsedCompileCommands;
+
     OutputLine processOutputLine(QString line);
     QString toOutputHtml(const KateBuildView::OutputLine &out);
     void addError(const OutputLine &err);
@@ -136,8 +152,20 @@ private:
     void displayBuildResult(const QString &message, KTextEditor::Message::MessageType level);
     void displayMessage(const QString &message, KTextEditor::Message::MessageType level);
 
-    void addProjectTarget();
+    void addProjectTargets();
+    QModelIndex createCMakeTargetSet(QModelIndex setIndex, const QString &name, const QCMakeFileApi &cmakeFA, const QString &cmakeConfig);
 
+    /** Check if given command line is allowed to be executed.
+     * Might ask the user for permission.
+     * @param cmdline full command line including program to check
+     * @return execution allowed?
+     */
+    bool isCommandLineAllowed(const QStringList &cmdline);
+
+    QString findCompileCommands(const QString& file) const;
+    CompileCommands parseCompileCommandsFile(const QString& compileCommandsFile) const;
+
+    KateBuildPlugin *m_plugin;
     KTextEditor::MainWindow *m_win;
     QWidget *m_toolView;
     Ui::build m_buildUi{};
@@ -166,8 +194,8 @@ private:
     int m_projectTargetsetRow = 0;
     bool m_firstBuild = true;
     DiagnosticsProvider m_diagnosticsProvider;
-    bool m_addDiagnostics = true;
-    bool m_autoSwitchToOutput = true;
+    QTimer m_saveProjTargetsTimer;
+    bool m_addingProjTargets = false;
 
     /**
      * current project plugin view, if any
@@ -192,6 +220,16 @@ public:
     int configPages() const override;
     KTextEditor::ConfigPage *configPage(int number = 0, QWidget *parent = nullptr) override;
 
-Q_SIGNALS:
-    void configChanged();
+    /**
+     * Read the non-session configurations
+     */
+    void readConfig();
+
+    void writeConfig() const;
+
+    bool m_addDiagnostics = true;
+    bool m_autoSwitchToOutput = true;
+
+    // hash of allowed and blacklisted command lines
+    std::map<QString, bool> m_commandLineToAllowedState;
 };
