@@ -45,7 +45,6 @@
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <kwidgetsaddons_version.h>
 
 #include <KColorUtils>
 #include <KFuzzyMatcher>
@@ -902,7 +901,8 @@ void GitWidget::parseStatusReady()
             continue;
         }
         const auto t = index.data(GitStatusModel::TreeItemType).toInt();
-        if (nodeIsExpanded.find(t) == nodeIsExpanded.end() || nodeIsExpanded[t]) {
+        auto it = nodeIsExpanded.find(t);
+        if (it == nodeIsExpanded.end() || it->second) {
             m_treeView->expand(index);
         } else {
             m_treeView->collapse(index);
@@ -1149,6 +1149,7 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
     if (!idx.isValid())
         return;
     auto treeItem = idx.data(GitStatusModel::TreeItemType);
+    auto treeItemParent = idx.parent().data(GitStatusModel::TreeItemType);
 
     if (treeItem == GitStatusModel::NodeChanges || treeItem == GitStatusModel::NodeUntrack) {
         QMenu menu(this);
@@ -1244,7 +1245,13 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
         } else if (act == launchDifftoolAct) {
             launchExternalDiffTool(idx.data(GitStatusModel::FileNameRole).toString(), staged);
         } else if (act == openFile) {
-            m_mainWin->openUrl(QUrl::fromLocalFile(file));
+            auto view = m_mainWin->openUrl(QUrl::fromLocalFile(file));
+            if (view && treeItemParent == GitStatusModel::NodeConflict) {
+                auto ranges = view->document()->searchText(view->document()->documentRange(), QStringLiteral("<<<<<<< HEAD"));
+                if (!ranges.isEmpty()) {
+                    view->setCursorPosition(ranges.first().start());
+                }
+            }
         }
     } else if (treeItem == GitStatusModel::NodeStage) {
         QMenu menu(this);
