@@ -98,7 +98,7 @@ FileDiagnostics KateProjectCodeAnalysisToolShellcheck::parseLine(const QString &
     d.severity = DiagnosticSeverity::Warning;
     int ln = elements[1].toInt() - 1;
     d.range = KTextEditor::Range(ln, 0, ln, -1);
-    return {url, {d}};
+    return {.uri = url, .diagnostics = {d}};
 }
 
 bool KateProjectCodeAnalysisToolShellcheck::isSuccessfulExitCode(int exitCode) const
