@@ -26,8 +26,8 @@
 
 #include "diagnostics/diagnosticview.h"
 
+#include <KTextEditor/Document>
 #include <ktexteditor/application.h>
-#include <ktexteditor/document.h>
 #include <ktexteditor/mainwindow.h>
 #include <ktexteditor/plugin.h>
 #include <ktexteditor/view.h>
